#!/usr/bin/python3
# ******************************************************************************
# Copyright (c) 2022 Huawei Technologies Co., Ltd.
# gala-anteater is licensed under Mulan PSL v2.
# You can use this software according to the terms and conditions of the Mulan PSL v2.
# You may obtain a copy of Mulan PSL v2 at:
#          http://license.coscl.org.cn/MulanPSL2
# THIS SOFTWARE IS PROVIDED ON AN "AS IS" BASIS, WITHOUT WARRANTIES OF ANY KIND,
# EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO NON-INFRINGEMENT,
# MERCHANTABILITY OR FIT FOR A PARTICULAR PURPOSE.
# See the Mulan PSL v2 for more details.
# ******************************************************************************/

import time
from functools import wraps

from anteater.utils.log import logger


def timer(func):
    """The timer decorator which records the time
    consumptions of wrapped fuction.
    """
    @wraps(func)
    def wrapper(*args, **kwargs):
        clock = time.time()
        result = func(*args, **kwargs)
        logger.info(f"{args[0].__class__.__name__}.{func.__name__} "
                    f"spends {time.time() - clock} seconds!")
        return result
    return wrapper
